import { select,
         csv,
         scaleLinear,
         max,
         scalePoint,
         axisLeft,
         axisBottom,
         format
       } from "d3"

const svg = select('svg');


const width = +svg.attr('width');
const height = +svg.attr("height");

const render = data => {
  const xValue = d => d.area
  const yValue = d => d.city
  
  const margin = { top:50,
                   right: 40,
                   bottom: 100,
                   left: 100
                 };
  const innerWidth = width - margin.left - margin.right
  const innerHeight = height - margin.top - margin.bottom
  
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.7);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);

  const xAxisTickFormat = number =>
  	format('.2s')(number)
  	.replace('G', 'B')
  	.replace('.0','');

  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth);
  
  g.append('g')
    .call(yAxis)
  	.select('.domain')
  		.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.append('text')
  	.attr('class', 'xLegend')
    .text('Some x values')
  	.attr('fill', 'black')
  	.attr('x', `${innerWidth / 2}`)
  	.attr('y', `${50}`);
  
  const radius = 20 / 2
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d=>xScale(xValue(d)))
  		.attr('r', radius);
  
  xAxisG.append('text')
  	.attr('class', 'title')
  	.attr('y', -innerHeight - 5)
  	.attr('x', `${innerWidth / 2}`)
  	.text('Some random data');
};


csv('data.csv').then(data => {
  data.forEach(d => {
  	d.area = +d.area;
  });
	render(data);
})